@@ -5,7 +5,7 @@ class APIError(Exception):
     """
 
     def __init__(self, error, http_error=None):
-        super().__init__(error["message"])
+        super().__init__(error)
         self._error = error
         self._http_error = http_error
 
@@ -31,6 +31,8 @@ class APIError(Exception):
 
 
 class RetryException(Exception):
-    """Request"""
+    """
+    Thrown by RESTClient's internally to represent a request that should be retried.
+    """
 
     pass
