@@ -8,7 +8,7 @@ import msgpack
 import websockets
 from pydantic import BaseModel
 
-from alpaca.common.time import TimeFrame
+from alpaca.data.time import TimeFrame
 from alpaca.common.types import RawData
 from alpaca.data.models import Bar, Quote, Trade
 
@@ -16,6 +16,10 @@ log = logging.getLogger(__name__)
 
 
 class BaseStream:
+    """
+    A base class for extracting out common functionality for websockets
+    """
+
     def __init__(
         self,
         endpoint: str,
@@ -167,8 +171,7 @@ class BaseStream:
                 result = Quote(msg["S"], msg)
 
             elif msg_type in ("b", "u", "d"):
-                timeframe = TimeFrame.Day if msg_type == "d" else TimeFrame.Minute
-                result = Bar(msg["S"], timeframe, msg)
+                result = Bar(msg["S"], msg)
 
         return result
 
